"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.age_range_type_pb2
import google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2
import google.ads.google_ads.v5.proto.enums.content_label_type_pb2
import google.ads.google_ads.v5.proto.enums.day_of_week_pb2
import google.ads.google_ads.v5.proto.enums.device_pb2
import google.ads.google_ads.v5.proto.enums.gender_type_pb2
import google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2
import google.ads.google_ads.v5.proto.enums.income_range_type_pb2
import google.ads.google_ads.v5.proto.enums.interaction_type_pb2
import google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2
import google.ads.google_ads.v5.proto.enums.listing_group_type_pb2
import google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2
import google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2
import google.ads.google_ads.v5.proto.enums.parental_status_type_pb2
import google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2
import google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2
import google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2
import google.ads.google_ads.v5.proto.enums.product_channel_pb2
import google.ads.google_ads.v5.proto.enums.product_condition_pb2
import google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2
import google.ads.google_ads.v5.proto.enums.product_type_level_pb2
import google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2
import google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2
import google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    MATCH_TYPE_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
        ...
    )
    def __init__(
        self,
        *,
        text: typing.Text = ...,
        match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_text", b"_text", "match_type", b"match_type", "text", b"text"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___KeywordInfo = KeywordInfo

class PlacementInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    URL_FIELD_NUMBER: builtins.int
    url: typing.Text = ...
    def __init__(
        self,
        *,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...

global___PlacementInfo = PlacementInfo

class MobileAppCategoryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MOBILE_APP_CATEGORY_CONSTANT_FIELD_NUMBER: builtins.int
    mobile_app_category_constant: typing.Text = ...
    def __init__(
        self,
        *,
        mobile_app_category_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_app_category_constant",
            b"_mobile_app_category_constant",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_app_category_constant",
            b"_mobile_app_category_constant",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_app_category_constant", b"_mobile_app_category_constant"
        ],
    ) -> typing_extensions.Literal["mobile_app_category_constant"]: ...

global___MobileAppCategoryInfo = MobileAppCategoryInfo

class MobileApplicationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    app_id: typing.Text = ...
    name: typing.Text = ...
    def __init__(
        self,
        *,
        app_id: typing.Text = ...,
        name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_name",
            b"_name",
            "app_id",
            b"app_id",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_name",
            b"_name",
            "app_id",
            b"app_id",
            "name",
            b"name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...

global___MobileApplicationInfo = MobileApplicationInfo

class LocationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    geo_target_constant: typing.Text = ...
    def __init__(
        self,
        *,
        geo_target_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_geo_target_constant",
            b"_geo_target_constant",
            "geo_target_constant",
            b"geo_target_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_geo_target_constant",
            b"_geo_target_constant",
            "geo_target_constant",
            b"geo_target_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_constant", b"_geo_target_constant"
        ],
    ) -> typing_extensions.Literal["geo_target_constant"]: ...

global___LocationInfo = LocationInfo

class DeviceInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.device_pb2.DeviceEnum.Device.V = ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.device_pb2.DeviceEnum.Device.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___DeviceInfo = DeviceInfo

class PreferredContentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2.PreferredContentTypeEnum.PreferredContentType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.preferred_content_type_pb2.PreferredContentTypeEnum.PreferredContentType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___PreferredContentInfo = PreferredContentInfo

class ListingGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    CASE_VALUE_FIELD_NUMBER: builtins.int
    PARENT_AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.listing_group_type_pb2.ListingGroupTypeEnum.ListingGroupType.V = (
        ...
    )
    parent_ad_group_criterion: typing.Text = ...
    @property
    def case_value(self) -> global___ListingDimensionInfo: ...
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.listing_group_type_pb2.ListingGroupTypeEnum.ListingGroupType.V = ...,
        case_value: typing.Optional[global___ListingDimensionInfo] = ...,
        parent_ad_group_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_parent_ad_group_criterion",
            b"_parent_ad_group_criterion",
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_parent_ad_group_criterion",
            b"_parent_ad_group_criterion",
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_ad_group_criterion", b"_parent_ad_group_criterion"
        ],
    ) -> typing_extensions.Literal["parent_ad_group_criterion"]: ...

global___ListingGroupInfo = ListingGroupInfo

class ListingScopeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DIMENSIONS_FIELD_NUMBER: builtins.int
    @property
    def dimensions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ListingDimensionInfo
    ]: ...
    def __init__(
        self,
        *,
        dimensions: typing.Optional[
            typing.Iterable[global___ListingDimensionInfo]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["dimensions", b"dimensions"]
    ) -> None: ...

global___ListingScopeInfo = ListingScopeInfo

class ListingDimensionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HOTEL_ID_FIELD_NUMBER: builtins.int
    HOTEL_CLASS_FIELD_NUMBER: builtins.int
    HOTEL_COUNTRY_REGION_FIELD_NUMBER: builtins.int
    HOTEL_STATE_FIELD_NUMBER: builtins.int
    HOTEL_CITY_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_FIELD_NUMBER: builtins.int
    PRODUCT_BRAND_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    PRODUCT_CONDITION_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE_FIELD_NUMBER: builtins.int
    PRODUCT_ITEM_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    UNKNOWN_LISTING_DIMENSION_FIELD_NUMBER: builtins.int
    @property
    def hotel_id(self) -> global___HotelIdInfo: ...
    @property
    def hotel_class(self) -> global___HotelClassInfo: ...
    @property
    def hotel_country_region(self) -> global___HotelCountryRegionInfo: ...
    @property
    def hotel_state(self) -> global___HotelStateInfo: ...
    @property
    def hotel_city(self) -> global___HotelCityInfo: ...
    @property
    def product_bidding_category(self) -> global___ProductBiddingCategoryInfo: ...
    @property
    def product_brand(self) -> global___ProductBrandInfo: ...
    @property
    def product_channel(self) -> global___ProductChannelInfo: ...
    @property
    def product_channel_exclusivity(self) -> global___ProductChannelExclusivityInfo: ...
    @property
    def product_condition(self) -> global___ProductConditionInfo: ...
    @property
    def product_custom_attribute(self) -> global___ProductCustomAttributeInfo: ...
    @property
    def product_item_id(self) -> global___ProductItemIdInfo: ...
    @property
    def product_type(self) -> global___ProductTypeInfo: ...
    @property
    def unknown_listing_dimension(self) -> global___UnknownListingDimensionInfo: ...
    def __init__(
        self,
        *,
        hotel_id: typing.Optional[global___HotelIdInfo] = ...,
        hotel_class: typing.Optional[global___HotelClassInfo] = ...,
        hotel_country_region: typing.Optional[global___HotelCountryRegionInfo] = ...,
        hotel_state: typing.Optional[global___HotelStateInfo] = ...,
        hotel_city: typing.Optional[global___HotelCityInfo] = ...,
        product_bidding_category: typing.Optional[
            global___ProductBiddingCategoryInfo
        ] = ...,
        product_brand: typing.Optional[global___ProductBrandInfo] = ...,
        product_channel: typing.Optional[global___ProductChannelInfo] = ...,
        product_channel_exclusivity: typing.Optional[
            global___ProductChannelExclusivityInfo
        ] = ...,
        product_condition: typing.Optional[global___ProductConditionInfo] = ...,
        product_custom_attribute: typing.Optional[
            global___ProductCustomAttributeInfo
        ] = ...,
        product_item_id: typing.Optional[global___ProductItemIdInfo] = ...,
        product_type: typing.Optional[global___ProductTypeInfo] = ...,
        unknown_listing_dimension: typing.Optional[
            global___UnknownListingDimensionInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["dimension", b"dimension"]
    ) -> typing_extensions.Literal[
        "hotel_id",
        "hotel_class",
        "hotel_country_region",
        "hotel_state",
        "hotel_city",
        "product_bidding_category",
        "product_brand",
        "product_channel",
        "product_channel_exclusivity",
        "product_condition",
        "product_custom_attribute",
        "product_item_id",
        "product_type",
        "unknown_listing_dimension",
    ]: ...

global___ListingDimensionInfo = ListingDimensionInfo

class HotelIdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___HotelIdInfo = HotelIdInfo

class HotelClassInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int = ...
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___HotelClassInfo = HotelClassInfo

class HotelCountryRegionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COUNTRY_REGION_CRITERION_FIELD_NUMBER: builtins.int
    country_region_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        country_region_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_region_criterion",
            b"_country_region_criterion",
            "country_region_criterion",
            b"country_region_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_region_criterion",
            b"_country_region_criterion",
            "country_region_criterion",
            b"country_region_criterion",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_country_region_criterion", b"_country_region_criterion"
        ],
    ) -> typing_extensions.Literal["country_region_criterion"]: ...

global___HotelCountryRegionInfo = HotelCountryRegionInfo

class HotelStateInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATE_CRITERION_FIELD_NUMBER: builtins.int
    state_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        state_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_state_criterion",
            b"_state_criterion",
            "state_criterion",
            b"state_criterion",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_state_criterion",
            b"_state_criterion",
            "state_criterion",
            b"state_criterion",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_state_criterion", b"_state_criterion"],
    ) -> typing_extensions.Literal["state_criterion"]: ...

global___HotelStateInfo = HotelStateInfo

class HotelCityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CITY_CRITERION_FIELD_NUMBER: builtins.int
    city_criterion: typing.Text = ...
    def __init__(
        self,
        *,
        city_criterion: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city_criterion", b"_city_criterion", "city_criterion", b"city_criterion"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city_criterion", b"_city_criterion", "city_criterion", b"city_criterion"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_city_criterion", b"_city_criterion"],
    ) -> typing_extensions.Literal["city_criterion"]: ...

global___HotelCityInfo = HotelCityInfo

class ProductBiddingCategoryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    id: builtins.int = ...
    country_code: typing.Text = ...
    level: google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = (
        ...
    )
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        country_code: typing.Text = ...,
        level: google.ads.google_ads.v5.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "country_code",
            b"country_code",
            "id",
            b"id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "level",
            b"level",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...

global___ProductBiddingCategoryInfo = ProductBiddingCategoryInfo

class ProductBrandInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductBrandInfo = ProductBrandInfo

class ProductChannelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_FIELD_NUMBER: builtins.int
    channel: google.ads.google_ads.v5.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = (
        ...
    )
    def __init__(
        self,
        *,
        channel: google.ads.google_ads.v5.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["channel", b"channel"]
    ) -> None: ...

global___ProductChannelInfo = ProductChannelInfo

class ProductChannelExclusivityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    channel_exclusivity: google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = (
        ...
    )
    def __init__(
        self,
        *,
        channel_exclusivity: google.ads.google_ads.v5.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel_exclusivity", b"channel_exclusivity"
        ],
    ) -> None: ...

global___ProductChannelExclusivityInfo = ProductChannelExclusivityInfo

class ProductConditionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONDITION_FIELD_NUMBER: builtins.int
    condition: google.ads.google_ads.v5.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = (
        ...
    )
    def __init__(
        self,
        *,
        condition: google.ads.google_ads.v5.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["condition", b"condition"]
    ) -> None: ...

global___ProductConditionInfo = ProductConditionInfo

class ProductCustomAttributeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    index: google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V = (
        ...
    )
    def __init__(
        self,
        *,
        value: typing.Text = ...,
        index: google.ads.google_ads.v5.proto.enums.product_custom_attribute_index_pb2.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_value", b"_value", "index", b"index", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductCustomAttributeInfo = ProductCustomAttributeInfo

class ProductItemIdInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    def __init__(
        self,
        *,
        value: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductItemIdInfo = ProductItemIdInfo

class ProductTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    value: typing.Text = ...
    level: google.ads.google_ads.v5.proto.enums.product_type_level_pb2.ProductTypeLevelEnum.ProductTypeLevel.V = (
        ...
    )
    def __init__(
        self,
        *,
        value: typing.Text = ...,
        level: google.ads.google_ads.v5.proto.enums.product_type_level_pb2.ProductTypeLevelEnum.ProductTypeLevel.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_value", b"_value", "level", b"level", "value", b"value"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_value", b"_value"]
    ) -> typing_extensions.Literal["value"]: ...

global___ProductTypeInfo = ProductTypeInfo

class UnknownListingDimensionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___UnknownListingDimensionInfo = UnknownListingDimensionInfo

class HotelDateSelectionTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___HotelDateSelectionTypeInfo = HotelDateSelectionTypeInfo

class HotelAdvanceBookingWindowInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MIN_DAYS_FIELD_NUMBER: builtins.int
    MAX_DAYS_FIELD_NUMBER: builtins.int
    min_days: builtins.int = ...
    max_days: builtins.int = ...
    def __init__(
        self,
        *,
        min_days: builtins.int = ...,
        max_days: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_max_days",
            b"_max_days",
            "_min_days",
            b"_min_days",
            "max_days",
            b"max_days",
            "min_days",
            b"min_days",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_max_days",
            b"_max_days",
            "_min_days",
            b"_min_days",
            "max_days",
            b"max_days",
            "min_days",
            b"min_days",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_max_days", b"_max_days"]
    ) -> typing_extensions.Literal["max_days"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_min_days", b"_min_days"]
    ) -> typing_extensions.Literal["min_days"]: ...

global___HotelAdvanceBookingWindowInfo = HotelAdvanceBookingWindowInfo

class HotelLengthOfStayInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MIN_NIGHTS_FIELD_NUMBER: builtins.int
    MAX_NIGHTS_FIELD_NUMBER: builtins.int
    min_nights: builtins.int = ...
    max_nights: builtins.int = ...
    def __init__(
        self,
        *,
        min_nights: builtins.int = ...,
        max_nights: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_max_nights",
            b"_max_nights",
            "_min_nights",
            b"_min_nights",
            "max_nights",
            b"max_nights",
            "min_nights",
            b"min_nights",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_max_nights",
            b"_max_nights",
            "_min_nights",
            b"_min_nights",
            "max_nights",
            b"max_nights",
            "min_nights",
            b"min_nights",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_max_nights", b"_max_nights"]
    ) -> typing_extensions.Literal["max_nights"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_min_nights", b"_min_nights"]
    ) -> typing_extensions.Literal["min_nights"]: ...

global___HotelLengthOfStayInfo = HotelLengthOfStayInfo

class HotelCheckInDayInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    def __init__(
        self,
        *,
        day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week"]
    ) -> None: ...

global___HotelCheckInDayInfo = HotelCheckInDayInfo

class InteractionTypeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.interaction_type_pb2.InteractionTypeEnum.InteractionType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.interaction_type_pb2.InteractionTypeEnum.InteractionType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___InteractionTypeInfo = InteractionTypeInfo

class AdScheduleInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    START_MINUTE_FIELD_NUMBER: builtins.int
    END_MINUTE_FIELD_NUMBER: builtins.int
    START_HOUR_FIELD_NUMBER: builtins.int
    END_HOUR_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    start_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = (
        ...
    )
    end_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = (
        ...
    )
    start_hour: builtins.int = ...
    end_hour: builtins.int = ...
    day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    def __init__(
        self,
        *,
        start_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = ...,
        end_minute: google.ads.google_ads.v5.proto.enums.minute_of_hour_pb2.MinuteOfHourEnum.MinuteOfHour.V = ...,
        start_hour: builtins.int = ...,
        end_hour: builtins.int = ...,
        day_of_week: google.ads.google_ads.v5.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_end_hour",
            b"_end_hour",
            "_start_hour",
            b"_start_hour",
            "end_hour",
            b"end_hour",
            "start_hour",
            b"start_hour",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_end_hour",
            b"_end_hour",
            "_start_hour",
            b"_start_hour",
            "day_of_week",
            b"day_of_week",
            "end_hour",
            b"end_hour",
            "end_minute",
            b"end_minute",
            "start_hour",
            b"start_hour",
            "start_minute",
            b"start_minute",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_end_hour", b"_end_hour"]
    ) -> typing_extensions.Literal["end_hour"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_start_hour", b"_start_hour"]
    ) -> typing_extensions.Literal["start_hour"]: ...

global___AdScheduleInfo = AdScheduleInfo

class AgeRangeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.age_range_type_pb2.AgeRangeTypeEnum.AgeRangeType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.age_range_type_pb2.AgeRangeTypeEnum.AgeRangeType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___AgeRangeInfo = AgeRangeInfo

class GenderInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.gender_type_pb2.GenderTypeEnum.GenderType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.gender_type_pb2.GenderTypeEnum.GenderType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___GenderInfo = GenderInfo

class IncomeRangeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.income_range_type_pb2.IncomeRangeTypeEnum.IncomeRangeType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.income_range_type_pb2.IncomeRangeTypeEnum.IncomeRangeType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___IncomeRangeInfo = IncomeRangeInfo

class ParentalStatusInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.parental_status_type_pb2.ParentalStatusTypeEnum.ParentalStatusType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.parental_status_type_pb2.ParentalStatusTypeEnum.ParentalStatusType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___ParentalStatusInfo = ParentalStatusInfo

class YouTubeVideoInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: typing.Text = ...
    def __init__(
        self,
        *,
        video_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_video_id", b"_video_id", "video_id", b"video_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_video_id", b"_video_id", "video_id", b"video_id"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_video_id", b"_video_id"]
    ) -> typing_extensions.Literal["video_id"]: ...

global___YouTubeVideoInfo = YouTubeVideoInfo

class YouTubeChannelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: typing.Text = ...
    def __init__(
        self,
        *,
        channel_id: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id", b"_channel_id", "channel_id", b"channel_id"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_channel_id", b"_channel_id", "channel_id", b"channel_id"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_channel_id", b"_channel_id"]
    ) -> typing_extensions.Literal["channel_id"]: ...

global___YouTubeChannelInfo = YouTubeChannelInfo

class UserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_LIST_FIELD_NUMBER: builtins.int
    user_list: typing.Text = ...
    def __init__(
        self,
        *,
        user_list: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_user_list", b"_user_list"]
    ) -> typing_extensions.Literal["user_list"]: ...

global___UserListInfo = UserListInfo

class ProximityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEO_POINT_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    RADIUS_UNITS_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    radius: builtins.float = ...
    radius_units: google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2.ProximityRadiusUnitsEnum.ProximityRadiusUnits.V = (
        ...
    )
    @property
    def geo_point(self) -> global___GeoPointInfo: ...
    @property
    def address(self) -> global___AddressInfo: ...
    def __init__(
        self,
        *,
        geo_point: typing.Optional[global___GeoPointInfo] = ...,
        radius: builtins.float = ...,
        radius_units: google.ads.google_ads.v5.proto.enums.proximity_radius_units_pb2.ProximityRadiusUnitsEnum.ProximityRadiusUnits.V = ...,
        address: typing.Optional[global___AddressInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_radius",
            b"_radius",
            "address",
            b"address",
            "geo_point",
            b"geo_point",
            "radius",
            b"radius",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_radius",
            b"_radius",
            "address",
            b"address",
            "geo_point",
            b"geo_point",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_radius", b"_radius"]
    ) -> typing_extensions.Literal["radius"]: ...

global___ProximityInfo = ProximityInfo

class GeoPointInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LONGITUDE_IN_MICRO_DEGREES_FIELD_NUMBER: builtins.int
    LATITUDE_IN_MICRO_DEGREES_FIELD_NUMBER: builtins.int
    longitude_in_micro_degrees: builtins.int = ...
    latitude_in_micro_degrees: builtins.int = ...
    def __init__(
        self,
        *,
        longitude_in_micro_degrees: builtins.int = ...,
        latitude_in_micro_degrees: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_latitude_in_micro_degrees",
            b"_latitude_in_micro_degrees",
            "_longitude_in_micro_degrees",
            b"_longitude_in_micro_degrees",
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_latitude_in_micro_degrees",
            b"_latitude_in_micro_degrees",
            "_longitude_in_micro_degrees",
            b"_longitude_in_micro_degrees",
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_latitude_in_micro_degrees", b"_latitude_in_micro_degrees"
        ],
    ) -> typing_extensions.Literal["latitude_in_micro_degrees"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_longitude_in_micro_degrees", b"_longitude_in_micro_degrees"
        ],
    ) -> typing_extensions.Literal["longitude_in_micro_degrees"]: ...

global___GeoPointInfo = GeoPointInfo

class AddressInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_NAME_FIELD_NUMBER: builtins.int
    STREET_ADDRESS_FIELD_NUMBER: builtins.int
    STREET_ADDRESS2_FIELD_NUMBER: builtins.int
    CITY_NAME_FIELD_NUMBER: builtins.int
    postal_code: typing.Text = ...
    province_code: typing.Text = ...
    country_code: typing.Text = ...
    province_name: typing.Text = ...
    street_address: typing.Text = ...
    street_address2: typing.Text = ...
    city_name: typing.Text = ...
    def __init__(
        self,
        *,
        postal_code: typing.Text = ...,
        province_code: typing.Text = ...,
        country_code: typing.Text = ...,
        province_name: typing.Text = ...,
        street_address: typing.Text = ...,
        street_address2: typing.Text = ...,
        city_name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_city_name",
            b"_city_name",
            "_country_code",
            b"_country_code",
            "_postal_code",
            b"_postal_code",
            "_province_code",
            b"_province_code",
            "_province_name",
            b"_province_name",
            "_street_address",
            b"_street_address",
            "_street_address2",
            b"_street_address2",
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_city_name",
            b"_city_name",
            "_country_code",
            b"_country_code",
            "_postal_code",
            b"_postal_code",
            "_province_code",
            b"_province_code",
            "_province_name",
            b"_province_name",
            "_street_address",
            b"_street_address",
            "_street_address2",
            b"_street_address2",
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_city_name", b"_city_name"]
    ) -> typing_extensions.Literal["city_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_postal_code", b"_postal_code"]
    ) -> typing_extensions.Literal["postal_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_province_code", b"_province_code"],
    ) -> typing_extensions.Literal["province_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_province_name", b"_province_name"],
    ) -> typing_extensions.Literal["province_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_street_address", b"_street_address"],
    ) -> typing_extensions.Literal["street_address"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_street_address2", b"_street_address2"],
    ) -> typing_extensions.Literal["street_address2"]: ...

global___AddressInfo = AddressInfo

class TopicInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOPIC_CONSTANT_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    topic_constant: typing.Text = ...
    path: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        topic_constant: typing.Text = ...,
        path: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_topic_constant", b"_topic_constant", "topic_constant", b"topic_constant"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_topic_constant",
            b"_topic_constant",
            "path",
            b"path",
            "topic_constant",
            b"topic_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_topic_constant", b"_topic_constant"],
    ) -> typing_extensions.Literal["topic_constant"]: ...

global___TopicInfo = TopicInfo

class LanguageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LANGUAGE_CONSTANT_FIELD_NUMBER: builtins.int
    language_constant: typing.Text = ...
    def __init__(
        self,
        *,
        language_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_language_constant",
            b"_language_constant",
            "language_constant",
            b"language_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_language_constant",
            b"_language_constant",
            "language_constant",
            b"language_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_language_constant", b"_language_constant"
        ],
    ) -> typing_extensions.Literal["language_constant"]: ...

global___LanguageInfo = LanguageInfo

class IpBlockInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    ip_address: typing.Text = ...
    def __init__(
        self,
        *,
        ip_address: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ip_address", b"_ip_address", "ip_address", b"ip_address"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ip_address", b"_ip_address", "ip_address", b"ip_address"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ip_address", b"_ip_address"]
    ) -> typing_extensions.Literal["ip_address"]: ...

global___IpBlockInfo = IpBlockInfo

class ContentLabelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.content_label_type_pb2.ContentLabelTypeEnum.ContentLabelType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.content_label_type_pb2.ContentLabelTypeEnum.ContentLabelType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___ContentLabelInfo = ContentLabelInfo

class CarrierInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CARRIER_CONSTANT_FIELD_NUMBER: builtins.int
    carrier_constant: typing.Text = ...
    def __init__(
        self,
        *,
        carrier_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_carrier_constant",
            b"_carrier_constant",
            "carrier_constant",
            b"carrier_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_carrier_constant",
            b"_carrier_constant",
            "carrier_constant",
            b"carrier_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_carrier_constant", b"_carrier_constant"
        ],
    ) -> typing_extensions.Literal["carrier_constant"]: ...

global___CarrierInfo = CarrierInfo

class UserInterestInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_INTEREST_CATEGORY_FIELD_NUMBER: builtins.int
    user_interest_category: typing.Text = ...
    def __init__(
        self,
        *,
        user_interest_category: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_user_interest_category",
            b"_user_interest_category",
            "user_interest_category",
            b"user_interest_category",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_user_interest_category",
            b"_user_interest_category",
            "user_interest_category",
            b"user_interest_category",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_user_interest_category", b"_user_interest_category"
        ],
    ) -> typing_extensions.Literal["user_interest_category"]: ...

global___UserInterestInfo = UserInterestInfo

class WebpageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CRITERION_NAME_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    criterion_name: typing.Text = ...
    @property
    def conditions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___WebpageConditionInfo
    ]: ...
    def __init__(
        self,
        *,
        criterion_name: typing.Text = ...,
        conditions: typing.Optional[
            typing.Iterable[global___WebpageConditionInfo]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_name", b"_criterion_name", "criterion_name", b"criterion_name"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_criterion_name",
            b"_criterion_name",
            "conditions",
            b"conditions",
            "criterion_name",
            b"criterion_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_criterion_name", b"_criterion_name"],
    ) -> typing_extensions.Literal["criterion_name"]: ...

global___WebpageInfo = WebpageInfo

class WebpageConditionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERAND_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    ARGUMENT_FIELD_NUMBER: builtins.int
    operand: google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2.WebpageConditionOperandEnum.WebpageConditionOperand.V = (
        ...
    )
    operator: google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2.WebpageConditionOperatorEnum.WebpageConditionOperator.V = (
        ...
    )
    argument: typing.Text = ...
    def __init__(
        self,
        *,
        operand: google.ads.google_ads.v5.proto.enums.webpage_condition_operand_pb2.WebpageConditionOperandEnum.WebpageConditionOperand.V = ...,
        operator: google.ads.google_ads.v5.proto.enums.webpage_condition_operator_pb2.WebpageConditionOperatorEnum.WebpageConditionOperator.V = ...,
        argument: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_argument", b"_argument", "argument", b"argument"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_argument",
            b"_argument",
            "argument",
            b"argument",
            "operand",
            b"operand",
            "operator",
            b"operator",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_argument", b"_argument"]
    ) -> typing_extensions.Literal["argument"]: ...

global___WebpageConditionInfo = WebpageConditionInfo

class OperatingSystemVersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATING_SYSTEM_VERSION_CONSTANT_FIELD_NUMBER: builtins.int
    operating_system_version_constant: typing.Text = ...
    def __init__(
        self,
        *,
        operating_system_version_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_operating_system_version_constant",
            b"_operating_system_version_constant",
            "operating_system_version_constant",
            b"operating_system_version_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_operating_system_version_constant",
            b"_operating_system_version_constant",
            "operating_system_version_constant",
            b"operating_system_version_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_operating_system_version_constant", b"_operating_system_version_constant"
        ],
    ) -> typing_extensions.Literal["operating_system_version_constant"]: ...

global___OperatingSystemVersionInfo = OperatingSystemVersionInfo

class AppPaymentModelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    type: google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2.AppPaymentModelTypeEnum.AppPaymentModelType.V = (
        ...
    )
    def __init__(
        self,
        *,
        type: google.ads.google_ads.v5.proto.enums.app_payment_model_type_pb2.AppPaymentModelTypeEnum.AppPaymentModelType.V = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["type", b"type"]
    ) -> None: ...

global___AppPaymentModelInfo = AppPaymentModelInfo

class MobileDeviceInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MOBILE_DEVICE_CONSTANT_FIELD_NUMBER: builtins.int
    mobile_device_constant: typing.Text = ...
    def __init__(
        self,
        *,
        mobile_device_constant: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_device_constant",
            b"_mobile_device_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_mobile_device_constant",
            b"_mobile_device_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_mobile_device_constant", b"_mobile_device_constant"
        ],
    ) -> typing_extensions.Literal["mobile_device_constant"]: ...

global___MobileDeviceInfo = MobileDeviceInfo

class CustomAffinityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOM_AFFINITY_FIELD_NUMBER: builtins.int
    custom_affinity: typing.Text = ...
    def __init__(
        self,
        *,
        custom_affinity: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_affinity",
            b"_custom_affinity",
            "custom_affinity",
            b"custom_affinity",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_affinity",
            b"_custom_affinity",
            "custom_affinity",
            b"custom_affinity",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_custom_affinity", b"_custom_affinity"],
    ) -> typing_extensions.Literal["custom_affinity"]: ...

global___CustomAffinityInfo = CustomAffinityInfo

class CustomIntentInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOM_INTENT_FIELD_NUMBER: builtins.int
    custom_intent: typing.Text = ...
    def __init__(
        self,
        *,
        custom_intent: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_intent", b"_custom_intent", "custom_intent", b"custom_intent"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_custom_intent", b"_custom_intent", "custom_intent", b"custom_intent"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_custom_intent", b"_custom_intent"],
    ) -> typing_extensions.Literal["custom_intent"]: ...

global___CustomIntentInfo = CustomIntentInfo

class LocationGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FEED_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANTS_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    RADIUS_UNITS_FIELD_NUMBER: builtins.int
    feed: typing.Text = ...
    geo_target_constants: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    radius: builtins.int = ...
    radius_units: google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits.V = (
        ...
    )
    def __init__(
        self,
        *,
        feed: typing.Text = ...,
        geo_target_constants: typing.Optional[typing.Iterable[typing.Text]] = ...,
        radius: builtins.int = ...,
        radius_units: google.ads.google_ads.v5.proto.enums.location_group_radius_units_pb2.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_feed",
            b"_feed",
            "_radius",
            b"_radius",
            "feed",
            b"feed",
            "radius",
            b"radius",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_feed",
            b"_feed",
            "_radius",
            b"_radius",
            "feed",
            b"feed",
            "geo_target_constants",
            b"geo_target_constants",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_feed", b"_feed"]
    ) -> typing_extensions.Literal["feed"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_radius", b"_radius"]
    ) -> typing_extensions.Literal["radius"]: ...

global___LocationGroupInfo = LocationGroupInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DsaPageFeedCriterionFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _DsaPageFeedCriterionField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            DsaPageFeedCriterionField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(0)
        UNKNOWN = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(1)
        PAGE_URL = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(2)
        LABEL = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(3)
    class DsaPageFeedCriterionField(metaclass=_DsaPageFeedCriterionField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(0)
    UNKNOWN = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(1)
    PAGE_URL = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(2)
    LABEL = DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField.V(3)
    def __init__(
        self,
    ) -> None: ...

global___DsaPageFeedCriterionFieldEnum = DsaPageFeedCriterionFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.criteria_pb2
import google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2
import google.ads.google_ads.v6.proto.enums.ad_network_type_pb2
import google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2
import google.ads.google_ads.v6.proto.enums.click_type_pb2
import google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2
import google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2
import google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2
import google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2
import google.ads.google_ads.v6.proto.enums.day_of_week_pb2
import google.ads.google_ads.v6.proto.enums.device_pb2
import google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2
import google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2
import google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2
import google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2
import google.ads.google_ads.v6.proto.enums.month_of_year_pb2
import google.ads.google_ads.v6.proto.enums.placeholder_type_pb2
import google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2
import google.ads.google_ads.v6.proto.enums.product_channel_pb2
import google.ads.google_ads.v6.proto.enums.product_condition_pb2
import google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2
import google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2
import google.ads.google_ads.v6.proto.enums.slot_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Segments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_DESTINATION_TYPE_FIELD_NUMBER: builtins.int
    AD_NETWORK_TYPE_FIELD_NUMBER: builtins.int
    BUDGET_CAMPAIGN_ASSOCIATION_STATUS_FIELD_NUMBER: builtins.int
    CLICK_TYPE_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_CATEGORY_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_NAME_FIELD_NUMBER: builtins.int
    CONVERSION_ADJUSTMENT_FIELD_NUMBER: builtins.int
    CONVERSION_ATTRIBUTION_EVENT_TYPE_FIELD_NUMBER: builtins.int
    CONVERSION_LAG_BUCKET_FIELD_NUMBER: builtins.int
    CONVERSION_OR_ADJUSTMENT_LAG_BUCKET_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    EXTERNAL_CONVERSION_SOURCE_FIELD_NUMBER: builtins.int
    GEO_TARGET_AIRPORT_FIELD_NUMBER: builtins.int
    GEO_TARGET_CANTON_FIELD_NUMBER: builtins.int
    GEO_TARGET_CITY_FIELD_NUMBER: builtins.int
    GEO_TARGET_COUNTRY_FIELD_NUMBER: builtins.int
    GEO_TARGET_COUNTY_FIELD_NUMBER: builtins.int
    GEO_TARGET_DISTRICT_FIELD_NUMBER: builtins.int
    GEO_TARGET_METRO_FIELD_NUMBER: builtins.int
    GEO_TARGET_MOST_SPECIFIC_LOCATION_FIELD_NUMBER: builtins.int
    GEO_TARGET_POSTAL_CODE_FIELD_NUMBER: builtins.int
    GEO_TARGET_PROVINCE_FIELD_NUMBER: builtins.int
    GEO_TARGET_REGION_FIELD_NUMBER: builtins.int
    GEO_TARGET_STATE_FIELD_NUMBER: builtins.int
    HOTEL_BOOKING_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    HOTEL_CENTER_ID_FIELD_NUMBER: builtins.int
    HOTEL_CHECK_IN_DATE_FIELD_NUMBER: builtins.int
    HOTEL_CHECK_IN_DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    HOTEL_CITY_FIELD_NUMBER: builtins.int
    HOTEL_CLASS_FIELD_NUMBER: builtins.int
    HOTEL_COUNTRY_FIELD_NUMBER: builtins.int
    HOTEL_DATE_SELECTION_TYPE_FIELD_NUMBER: builtins.int
    HOTEL_LENGTH_OF_STAY_FIELD_NUMBER: builtins.int
    HOTEL_RATE_RULE_ID_FIELD_NUMBER: builtins.int
    HOTEL_RATE_TYPE_FIELD_NUMBER: builtins.int
    HOTEL_PRICE_BUCKET_FIELD_NUMBER: builtins.int
    HOTEL_STATE_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    INTERACTION_ON_THIS_EXTENSION_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    MONTH_OF_YEAR_FIELD_NUMBER: builtins.int
    PARTNER_HOTEL_ID_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPE_FIELD_NUMBER: builtins.int
    PRODUCT_AGGREGATOR_ID_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL1_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL2_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL3_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL4_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_LEVEL5_FIELD_NUMBER: builtins.int
    PRODUCT_BRAND_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_FIELD_NUMBER: builtins.int
    PRODUCT_CHANNEL_EXCLUSIVITY_FIELD_NUMBER: builtins.int
    PRODUCT_CONDITION_FIELD_NUMBER: builtins.int
    PRODUCT_COUNTRY_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE0_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE1_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE2_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE3_FIELD_NUMBER: builtins.int
    PRODUCT_CUSTOM_ATTRIBUTE4_FIELD_NUMBER: builtins.int
    PRODUCT_ITEM_ID_FIELD_NUMBER: builtins.int
    PRODUCT_LANGUAGE_FIELD_NUMBER: builtins.int
    PRODUCT_MERCHANT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_STORE_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TITLE_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L1_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L2_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L3_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L4_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_L5_FIELD_NUMBER: builtins.int
    QUARTER_FIELD_NUMBER: builtins.int
    SEARCH_ENGINE_RESULTS_PAGE_TYPE_FIELD_NUMBER: builtins.int
    SEARCH_TERM_MATCH_TYPE_FIELD_NUMBER: builtins.int
    SLOT_FIELD_NUMBER: builtins.int
    WEBPAGE_FIELD_NUMBER: builtins.int
    WEEK_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    ad_destination_type: google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2.AdDestinationTypeEnum.AdDestinationType.V = (
        ...
    )
    ad_network_type: google.ads.google_ads.v6.proto.enums.ad_network_type_pb2.AdNetworkTypeEnum.AdNetworkType.V = (
        ...
    )
    click_type: google.ads.google_ads.v6.proto.enums.click_type_pb2.ClickTypeEnum.ClickType.V = (
        ...
    )
    conversion_action: typing.Text = ...
    conversion_action_category: google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = (
        ...
    )
    conversion_action_name: typing.Text = ...
    conversion_adjustment: builtins.bool = ...
    conversion_attribution_event_type: google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2.ConversionAttributionEventTypeEnum.ConversionAttributionEventType.V = (
        ...
    )
    conversion_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2.ConversionLagBucketEnum.ConversionLagBucket.V = (
        ...
    )
    conversion_or_adjustment_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V = (
        ...
    )
    date: typing.Text = ...
    day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    device: google.ads.google_ads.v6.proto.enums.device_pb2.DeviceEnum.Device.V = ...
    external_conversion_source: google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2.ExternalConversionSourceEnum.ExternalConversionSource.V = (
        ...
    )
    geo_target_airport: typing.Text = ...
    geo_target_canton: typing.Text = ...
    geo_target_city: typing.Text = ...
    geo_target_country: typing.Text = ...
    geo_target_county: typing.Text = ...
    geo_target_district: typing.Text = ...
    geo_target_metro: typing.Text = ...
    geo_target_most_specific_location: typing.Text = ...
    geo_target_postal_code: typing.Text = ...
    geo_target_province: typing.Text = ...
    geo_target_region: typing.Text = ...
    geo_target_state: typing.Text = ...
    hotel_booking_window_days: builtins.int = ...
    hotel_center_id: builtins.int = ...
    hotel_check_in_date: typing.Text = ...
    hotel_check_in_day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = (
        ...
    )
    hotel_city: typing.Text = ...
    hotel_class: builtins.int = ...
    hotel_country: typing.Text = ...
    hotel_date_selection_type: google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = (
        ...
    )
    hotel_length_of_stay: builtins.int = ...
    hotel_rate_rule_id: typing.Text = ...
    hotel_rate_type: google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2.HotelRateTypeEnum.HotelRateType.V = (
        ...
    )
    hotel_price_bucket: google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2.HotelPriceBucketEnum.HotelPriceBucket.V = (
        ...
    )
    hotel_state: typing.Text = ...
    hour: builtins.int = ...
    interaction_on_this_extension: builtins.bool = ...
    month: typing.Text = ...
    month_of_year: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = (
        ...
    )
    partner_hotel_id: typing.Text = ...
    placeholder_type: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = (
        ...
    )
    product_aggregator_id: builtins.int = ...
    product_bidding_category_level1: typing.Text = ...
    product_bidding_category_level2: typing.Text = ...
    product_bidding_category_level3: typing.Text = ...
    product_bidding_category_level4: typing.Text = ...
    product_bidding_category_level5: typing.Text = ...
    product_brand: typing.Text = ...
    product_channel: google.ads.google_ads.v6.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = (
        ...
    )
    product_channel_exclusivity: google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = (
        ...
    )
    product_condition: google.ads.google_ads.v6.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = (
        ...
    )
    product_country: typing.Text = ...
    product_custom_attribute0: typing.Text = ...
    product_custom_attribute1: typing.Text = ...
    product_custom_attribute2: typing.Text = ...
    product_custom_attribute3: typing.Text = ...
    product_custom_attribute4: typing.Text = ...
    product_item_id: typing.Text = ...
    product_language: typing.Text = ...
    product_merchant_id: builtins.int = ...
    product_store_id: typing.Text = ...
    product_title: typing.Text = ...
    product_type_l1: typing.Text = ...
    product_type_l2: typing.Text = ...
    product_type_l3: typing.Text = ...
    product_type_l4: typing.Text = ...
    product_type_l5: typing.Text = ...
    quarter: typing.Text = ...
    search_engine_results_page_type: google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType.V = (
        ...
    )
    search_term_match_type: google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2.SearchTermMatchTypeEnum.SearchTermMatchType.V = (
        ...
    )
    slot: google.ads.google_ads.v6.proto.enums.slot_pb2.SlotEnum.Slot.V = ...
    webpage: typing.Text = ...
    week: typing.Text = ...
    year: builtins.int = ...
    @property
    def budget_campaign_association_status(
        self,
    ) -> global___BudgetCampaignAssociationStatus: ...
    @property
    def keyword(self) -> global___Keyword: ...
    def __init__(
        self,
        *,
        ad_destination_type: google.ads.google_ads.v6.proto.enums.ad_destination_type_pb2.AdDestinationTypeEnum.AdDestinationType.V = ...,
        ad_network_type: google.ads.google_ads.v6.proto.enums.ad_network_type_pb2.AdNetworkTypeEnum.AdNetworkType.V = ...,
        budget_campaign_association_status: typing.Optional[
            global___BudgetCampaignAssociationStatus
        ] = ...,
        click_type: google.ads.google_ads.v6.proto.enums.click_type_pb2.ClickTypeEnum.ClickType.V = ...,
        conversion_action: typing.Text = ...,
        conversion_action_category: google.ads.google_ads.v6.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = ...,
        conversion_action_name: typing.Text = ...,
        conversion_adjustment: builtins.bool = ...,
        conversion_attribution_event_type: google.ads.google_ads.v6.proto.enums.conversion_attribution_event_type_pb2.ConversionAttributionEventTypeEnum.ConversionAttributionEventType.V = ...,
        conversion_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_lag_bucket_pb2.ConversionLagBucketEnum.ConversionLagBucket.V = ...,
        conversion_or_adjustment_lag_bucket: google.ads.google_ads.v6.proto.enums.conversion_or_adjustment_lag_bucket_pb2.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket.V = ...,
        date: typing.Text = ...,
        day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
        device: google.ads.google_ads.v6.proto.enums.device_pb2.DeviceEnum.Device.V = ...,
        external_conversion_source: google.ads.google_ads.v6.proto.enums.external_conversion_source_pb2.ExternalConversionSourceEnum.ExternalConversionSource.V = ...,
        geo_target_airport: typing.Text = ...,
        geo_target_canton: typing.Text = ...,
        geo_target_city: typing.Text = ...,
        geo_target_country: typing.Text = ...,
        geo_target_county: typing.Text = ...,
        geo_target_district: typing.Text = ...,
        geo_target_metro: typing.Text = ...,
        geo_target_most_specific_location: typing.Text = ...,
        geo_target_postal_code: typing.Text = ...,
        geo_target_province: typing.Text = ...,
        geo_target_region: typing.Text = ...,
        geo_target_state: typing.Text = ...,
        hotel_booking_window_days: builtins.int = ...,
        hotel_center_id: builtins.int = ...,
        hotel_check_in_date: typing.Text = ...,
        hotel_check_in_day_of_week: google.ads.google_ads.v6.proto.enums.day_of_week_pb2.DayOfWeekEnum.DayOfWeek.V = ...,
        hotel_city: typing.Text = ...,
        hotel_class: builtins.int = ...,
        hotel_country: typing.Text = ...,
        hotel_date_selection_type: google.ads.google_ads.v6.proto.enums.hotel_date_selection_type_pb2.HotelDateSelectionTypeEnum.HotelDateSelectionType.V = ...,
        hotel_length_of_stay: builtins.int = ...,
        hotel_rate_rule_id: typing.Text = ...,
        hotel_rate_type: google.ads.google_ads.v6.proto.enums.hotel_rate_type_pb2.HotelRateTypeEnum.HotelRateType.V = ...,
        hotel_price_bucket: google.ads.google_ads.v6.proto.enums.hotel_price_bucket_pb2.HotelPriceBucketEnum.HotelPriceBucket.V = ...,
        hotel_state: typing.Text = ...,
        hour: builtins.int = ...,
        interaction_on_this_extension: builtins.bool = ...,
        keyword: typing.Optional[global___Keyword] = ...,
        month: typing.Text = ...,
        month_of_year: google.ads.google_ads.v6.proto.enums.month_of_year_pb2.MonthOfYearEnum.MonthOfYear.V = ...,
        partner_hotel_id: typing.Text = ...,
        placeholder_type: google.ads.google_ads.v6.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V = ...,
        product_aggregator_id: builtins.int = ...,
        product_bidding_category_level1: typing.Text = ...,
        product_bidding_category_level2: typing.Text = ...,
        product_bidding_category_level3: typing.Text = ...,
        product_bidding_category_level4: typing.Text = ...,
        product_bidding_category_level5: typing.Text = ...,
        product_brand: typing.Text = ...,
        product_channel: google.ads.google_ads.v6.proto.enums.product_channel_pb2.ProductChannelEnum.ProductChannel.V = ...,
        product_channel_exclusivity: google.ads.google_ads.v6.proto.enums.product_channel_exclusivity_pb2.ProductChannelExclusivityEnum.ProductChannelExclusivity.V = ...,
        product_condition: google.ads.google_ads.v6.proto.enums.product_condition_pb2.ProductConditionEnum.ProductCondition.V = ...,
        product_country: typing.Text = ...,
        product_custom_attribute0: typing.Text = ...,
        product_custom_attribute1: typing.Text = ...,
        product_custom_attribute2: typing.Text = ...,
        product_custom_attribute3: typing.Text = ...,
        product_custom_attribute4: typing.Text = ...,
        product_item_id: typing.Text = ...,
        product_language: typing.Text = ...,
        product_merchant_id: builtins.int = ...,
        product_store_id: typing.Text = ...,
        product_title: typing.Text = ...,
        product_type_l1: typing.Text = ...,
        product_type_l2: typing.Text = ...,
        product_type_l3: typing.Text = ...,
        product_type_l4: typing.Text = ...,
        product_type_l5: typing.Text = ...,
        quarter: typing.Text = ...,
        search_engine_results_page_type: google.ads.google_ads.v6.proto.enums.search_engine_results_page_type_pb2.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType.V = ...,
        search_term_match_type: google.ads.google_ads.v6.proto.enums.search_term_match_type_pb2.SearchTermMatchTypeEnum.SearchTermMatchType.V = ...,
        slot: google.ads.google_ads.v6.proto.enums.slot_pb2.SlotEnum.Slot.V = ...,
        webpage: typing.Text = ...,
        week: typing.Text = ...,
        year: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "conversion_action",
            b"conversion_action",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "date",
            b"date",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "partner_hotel_id",
            b"partner_hotel_id",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_conversion_action",
            b"_conversion_action",
            "_conversion_action_name",
            b"_conversion_action_name",
            "_conversion_adjustment",
            b"_conversion_adjustment",
            "_date",
            b"_date",
            "_geo_target_airport",
            b"_geo_target_airport",
            "_geo_target_canton",
            b"_geo_target_canton",
            "_geo_target_city",
            b"_geo_target_city",
            "_geo_target_country",
            b"_geo_target_country",
            "_geo_target_county",
            b"_geo_target_county",
            "_geo_target_district",
            b"_geo_target_district",
            "_geo_target_metro",
            b"_geo_target_metro",
            "_geo_target_most_specific_location",
            b"_geo_target_most_specific_location",
            "_geo_target_postal_code",
            b"_geo_target_postal_code",
            "_geo_target_province",
            b"_geo_target_province",
            "_geo_target_region",
            b"_geo_target_region",
            "_geo_target_state",
            b"_geo_target_state",
            "_hotel_booking_window_days",
            b"_hotel_booking_window_days",
            "_hotel_center_id",
            b"_hotel_center_id",
            "_hotel_check_in_date",
            b"_hotel_check_in_date",
            "_hotel_city",
            b"_hotel_city",
            "_hotel_class",
            b"_hotel_class",
            "_hotel_country",
            b"_hotel_country",
            "_hotel_length_of_stay",
            b"_hotel_length_of_stay",
            "_hotel_rate_rule_id",
            b"_hotel_rate_rule_id",
            "_hotel_state",
            b"_hotel_state",
            "_hour",
            b"_hour",
            "_interaction_on_this_extension",
            b"_interaction_on_this_extension",
            "_month",
            b"_month",
            "_partner_hotel_id",
            b"_partner_hotel_id",
            "_product_aggregator_id",
            b"_product_aggregator_id",
            "_product_bidding_category_level1",
            b"_product_bidding_category_level1",
            "_product_bidding_category_level2",
            b"_product_bidding_category_level2",
            "_product_bidding_category_level3",
            b"_product_bidding_category_level3",
            "_product_bidding_category_level4",
            b"_product_bidding_category_level4",
            "_product_bidding_category_level5",
            b"_product_bidding_category_level5",
            "_product_brand",
            b"_product_brand",
            "_product_country",
            b"_product_country",
            "_product_custom_attribute0",
            b"_product_custom_attribute0",
            "_product_custom_attribute1",
            b"_product_custom_attribute1",
            "_product_custom_attribute2",
            b"_product_custom_attribute2",
            "_product_custom_attribute3",
            b"_product_custom_attribute3",
            "_product_custom_attribute4",
            b"_product_custom_attribute4",
            "_product_item_id",
            b"_product_item_id",
            "_product_language",
            b"_product_language",
            "_product_merchant_id",
            b"_product_merchant_id",
            "_product_store_id",
            b"_product_store_id",
            "_product_title",
            b"_product_title",
            "_product_type_l1",
            b"_product_type_l1",
            "_product_type_l2",
            b"_product_type_l2",
            "_product_type_l3",
            b"_product_type_l3",
            "_product_type_l4",
            b"_product_type_l4",
            "_product_type_l5",
            b"_product_type_l5",
            "_quarter",
            b"_quarter",
            "_webpage",
            b"_webpage",
            "_week",
            b"_week",
            "_year",
            b"_year",
            "ad_destination_type",
            b"ad_destination_type",
            "ad_network_type",
            b"ad_network_type",
            "budget_campaign_association_status",
            b"budget_campaign_association_status",
            "click_type",
            b"click_type",
            "conversion_action",
            b"conversion_action",
            "conversion_action_category",
            b"conversion_action_category",
            "conversion_action_name",
            b"conversion_action_name",
            "conversion_adjustment",
            b"conversion_adjustment",
            "conversion_attribution_event_type",
            b"conversion_attribution_event_type",
            "conversion_lag_bucket",
            b"conversion_lag_bucket",
            "conversion_or_adjustment_lag_bucket",
            b"conversion_or_adjustment_lag_bucket",
            "date",
            b"date",
            "day_of_week",
            b"day_of_week",
            "device",
            b"device",
            "external_conversion_source",
            b"external_conversion_source",
            "geo_target_airport",
            b"geo_target_airport",
            "geo_target_canton",
            b"geo_target_canton",
            "geo_target_city",
            b"geo_target_city",
            "geo_target_country",
            b"geo_target_country",
            "geo_target_county",
            b"geo_target_county",
            "geo_target_district",
            b"geo_target_district",
            "geo_target_metro",
            b"geo_target_metro",
            "geo_target_most_specific_location",
            b"geo_target_most_specific_location",
            "geo_target_postal_code",
            b"geo_target_postal_code",
            "geo_target_province",
            b"geo_target_province",
            "geo_target_region",
            b"geo_target_region",
            "geo_target_state",
            b"geo_target_state",
            "hotel_booking_window_days",
            b"hotel_booking_window_days",
            "hotel_center_id",
            b"hotel_center_id",
            "hotel_check_in_date",
            b"hotel_check_in_date",
            "hotel_check_in_day_of_week",
            b"hotel_check_in_day_of_week",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country",
            b"hotel_country",
            "hotel_date_selection_type",
            b"hotel_date_selection_type",
            "hotel_length_of_stay",
            b"hotel_length_of_stay",
            "hotel_price_bucket",
            b"hotel_price_bucket",
            "hotel_rate_rule_id",
            b"hotel_rate_rule_id",
            "hotel_rate_type",
            b"hotel_rate_type",
            "hotel_state",
            b"hotel_state",
            "hour",
            b"hour",
            "interaction_on_this_extension",
            b"interaction_on_this_extension",
            "keyword",
            b"keyword",
            "month",
            b"month",
            "month_of_year",
            b"month_of_year",
            "partner_hotel_id",
            b"partner_hotel_id",
            "placeholder_type",
            b"placeholder_type",
            "product_aggregator_id",
            b"product_aggregator_id",
            "product_bidding_category_level1",
            b"product_bidding_category_level1",
            "product_bidding_category_level2",
            b"product_bidding_category_level2",
            "product_bidding_category_level3",
            b"product_bidding_category_level3",
            "product_bidding_category_level4",
            b"product_bidding_category_level4",
            "product_bidding_category_level5",
            b"product_bidding_category_level5",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_country",
            b"product_country",
            "product_custom_attribute0",
            b"product_custom_attribute0",
            "product_custom_attribute1",
            b"product_custom_attribute1",
            "product_custom_attribute2",
            b"product_custom_attribute2",
            "product_custom_attribute3",
            b"product_custom_attribute3",
            "product_custom_attribute4",
            b"product_custom_attribute4",
            "product_item_id",
            b"product_item_id",
            "product_language",
            b"product_language",
            "product_merchant_id",
            b"product_merchant_id",
            "product_store_id",
            b"product_store_id",
            "product_title",
            b"product_title",
            "product_type_l1",
            b"product_type_l1",
            "product_type_l2",
            b"product_type_l2",
            "product_type_l3",
            b"product_type_l3",
            "product_type_l4",
            b"product_type_l4",
            "product_type_l5",
            b"product_type_l5",
            "quarter",
            b"quarter",
            "search_engine_results_page_type",
            b"search_engine_results_page_type",
            "search_term_match_type",
            b"search_term_match_type",
            "slot",
            b"slot",
            "webpage",
            b"webpage",
            "week",
            b"week",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions.Literal["conversion_action"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_action_name", b"_conversion_action_name"
        ],
    ) -> typing_extensions.Literal["conversion_action_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_conversion_adjustment", b"_conversion_adjustment"
        ],
    ) -> typing_extensions.Literal["conversion_adjustment"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_date", b"_date"]
    ) -> typing_extensions.Literal["date"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_airport", b"_geo_target_airport"
        ],
    ) -> typing_extensions.Literal["geo_target_airport"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_canton", b"_geo_target_canton"
        ],
    ) -> typing_extensions.Literal["geo_target_canton"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_geo_target_city", b"_geo_target_city"],
    ) -> typing_extensions.Literal["geo_target_city"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_country", b"_geo_target_country"
        ],
    ) -> typing_extensions.Literal["geo_target_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_county", b"_geo_target_county"
        ],
    ) -> typing_extensions.Literal["geo_target_county"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_district", b"_geo_target_district"
        ],
    ) -> typing_extensions.Literal["geo_target_district"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_metro", b"_geo_target_metro"
        ],
    ) -> typing_extensions.Literal["geo_target_metro"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_most_specific_location", b"_geo_target_most_specific_location"
        ],
    ) -> typing_extensions.Literal["geo_target_most_specific_location"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_postal_code", b"_geo_target_postal_code"
        ],
    ) -> typing_extensions.Literal["geo_target_postal_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_province", b"_geo_target_province"
        ],
    ) -> typing_extensions.Literal["geo_target_province"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_region", b"_geo_target_region"
        ],
    ) -> typing_extensions.Literal["geo_target_region"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_geo_target_state", b"_geo_target_state"
        ],
    ) -> typing_extensions.Literal["geo_target_state"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_booking_window_days", b"_hotel_booking_window_days"
        ],
    ) -> typing_extensions.Literal["hotel_booking_window_days"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_hotel_center_id", b"_hotel_center_id"],
    ) -> typing_extensions.Literal["hotel_center_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_check_in_date", b"_hotel_check_in_date"
        ],
    ) -> typing_extensions.Literal["hotel_check_in_date"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_city", b"_hotel_city"]
    ) -> typing_extensions.Literal["hotel_city"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_class", b"_hotel_class"]
    ) -> typing_extensions.Literal["hotel_class"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_hotel_country", b"_hotel_country"],
    ) -> typing_extensions.Literal["hotel_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_length_of_stay", b"_hotel_length_of_stay"
        ],
    ) -> typing_extensions.Literal["hotel_length_of_stay"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_hotel_rate_rule_id", b"_hotel_rate_rule_id"
        ],
    ) -> typing_extensions.Literal["hotel_rate_rule_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hotel_state", b"_hotel_state"]
    ) -> typing_extensions.Literal["hotel_state"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_hour", b"_hour"]
    ) -> typing_extensions.Literal["hour"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_interaction_on_this_extension", b"_interaction_on_this_extension"
        ],
    ) -> typing_extensions.Literal["interaction_on_this_extension"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_month", b"_month"]
    ) -> typing_extensions.Literal["month"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_partner_hotel_id", b"_partner_hotel_id"
        ],
    ) -> typing_extensions.Literal["partner_hotel_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_aggregator_id", b"_product_aggregator_id"
        ],
    ) -> typing_extensions.Literal["product_aggregator_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level1", b"_product_bidding_category_level1"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level2", b"_product_bidding_category_level2"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level3", b"_product_bidding_category_level3"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level4", b"_product_bidding_category_level4"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_level5", b"_product_bidding_category_level5"
        ],
    ) -> typing_extensions.Literal["product_bidding_category_level5"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_brand", b"_product_brand"],
    ) -> typing_extensions.Literal["product_brand"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_country", b"_product_country"],
    ) -> typing_extensions.Literal["product_country"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute0", b"_product_custom_attribute0"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute0"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute1", b"_product_custom_attribute1"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute2", b"_product_custom_attribute2"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute3", b"_product_custom_attribute3"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_custom_attribute4", b"_product_custom_attribute4"
        ],
    ) -> typing_extensions.Literal["product_custom_attribute4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_item_id", b"_product_item_id"],
    ) -> typing_extensions.Literal["product_item_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_language", b"_product_language"
        ],
    ) -> typing_extensions.Literal["product_language"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_merchant_id", b"_product_merchant_id"
        ],
    ) -> typing_extensions.Literal["product_merchant_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_store_id", b"_product_store_id"
        ],
    ) -> typing_extensions.Literal["product_store_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_title", b"_product_title"],
    ) -> typing_extensions.Literal["product_title"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l1", b"_product_type_l1"],
    ) -> typing_extensions.Literal["product_type_l1"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l2", b"_product_type_l2"],
    ) -> typing_extensions.Literal["product_type_l2"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l3", b"_product_type_l3"],
    ) -> typing_extensions.Literal["product_type_l3"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l4", b"_product_type_l4"],
    ) -> typing_extensions.Literal["product_type_l4"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_product_type_l5", b"_product_type_l5"],
    ) -> typing_extensions.Literal["product_type_l5"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_quarter", b"_quarter"]
    ) -> typing_extensions.Literal["quarter"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_webpage", b"_webpage"]
    ) -> typing_extensions.Literal["webpage"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_week", b"_week"]
    ) -> typing_extensions.Literal["week"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_year", b"_year"]
    ) -> typing_extensions.Literal["year"]: ...

global___Segments = Segments

class Keyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    ad_group_criterion: typing.Text = ...
    @property
    def info(
        self,
    ) -> google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo: ...
    def __init__(
        self,
        *,
        ad_group_criterion: typing.Text = ...,
        info: typing.Optional[
            google.ads.google_ads.v6.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "ad_group_criterion",
            b"ad_group_criterion",
            "info",
            b"info",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_ad_group_criterion", b"_ad_group_criterion"
        ],
    ) -> typing_extensions.Literal["ad_group_criterion"]: ...

global___Keyword = Keyword

class BudgetCampaignAssociationStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CAMPAIGN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    campaign: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2.BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V = (
        ...
    )
    def __init__(
        self,
        *,
        campaign: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.budget_campaign_association_status_pb2.BudgetCampaignAssociationStatusEnum.BudgetCampaignAssociationStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign", b"_campaign", "campaign", b"campaign"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_campaign", b"_campaign", "campaign", b"campaign", "status", b"status"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...

global___BudgetCampaignAssociationStatus = BudgetCampaignAssociationStatus



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.extensions_pb2
import google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2
import google.ads.google_ads.v5.proto.resources.ad_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetRecommendationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetRecommendationRequest = GetRecommendationRequest

class ApplyRecommendationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ApplyRecommendationOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[global___ApplyRecommendationOperation]
        ] = ...,
        partial_failure: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
        ],
    ) -> None: ...

global___ApplyRecommendationRequest = ApplyRecommendationRequest

class ApplyRecommendationOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class CampaignBudgetParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NEW_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        @property
        def new_budget_amount_micros(
            self,
        ) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            new_budget_amount_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "new_budget_amount_micros", b"new_budget_amount_micros"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "new_budget_amount_micros", b"new_budget_amount_micros"
            ],
        ) -> None: ...
    class TextAdParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AD_FIELD_NUMBER: builtins.int
        @property
        def ad(self) -> google.ads.google_ads.v5.proto.resources.ad_pb2.Ad: ...
        def __init__(
            self,
            *,
            ad: typing.Optional[
                google.ads.google_ads.v5.proto.resources.ad_pb2.Ad
            ] = ...,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions.Literal["ad", b"ad"]
        ) -> builtins.bool: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["ad", b"ad"]
        ) -> None: ...
    class KeywordParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AD_GROUP_FIELD_NUMBER: builtins.int
        MATCH_TYPE_FIELD_NUMBER: builtins.int
        CPC_BID_MICROS_FIELD_NUMBER: builtins.int
        match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
            ...
        )
        @property
        def ad_group(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def cpc_bid_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            ad_group: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
            match_type: google.ads.google_ads.v5.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
            cpc_bid_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "ad_group", b"ad_group", "cpc_bid_micros", b"cpc_bid_micros"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "ad_group",
                b"ad_group",
                "cpc_bid_micros",
                b"cpc_bid_micros",
                "match_type",
                b"match_type",
            ],
        ) -> None: ...
    class TargetCpaOptInParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
        NEW_CAMPAIGN_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        @property
        def target_cpa_micros(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def new_campaign_budget_amount_micros(
            self,
        ) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            target_cpa_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
            new_campaign_budget_amount_micros: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_cpa_micros",
                b"target_cpa_micros",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_cpa_micros",
                b"target_cpa_micros",
            ],
        ) -> None: ...
    class TargetRoasOptInParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TARGET_ROAS_FIELD_NUMBER: builtins.int
        NEW_CAMPAIGN_BUDGET_AMOUNT_MICROS_FIELD_NUMBER: builtins.int
        target_roas: builtins.float = ...
        new_campaign_budget_amount_micros: builtins.int = ...
        def __init__(
            self,
            *,
            target_roas: builtins.float = ...,
            new_campaign_budget_amount_micros: builtins.int = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_new_campaign_budget_amount_micros",
                b"_new_campaign_budget_amount_micros",
                "_target_roas",
                b"_target_roas",
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_roas",
                b"target_roas",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_new_campaign_budget_amount_micros",
                b"_new_campaign_budget_amount_micros",
                "_target_roas",
                b"_target_roas",
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_roas",
                b"target_roas",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_new_campaign_budget_amount_micros",
                b"_new_campaign_budget_amount_micros",
            ],
        ) -> typing_extensions.Literal["new_campaign_budget_amount_micros"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"],
        ) -> typing_extensions.Literal["target_roas"]: ...
    class CalloutExtensionParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CALLOUT_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def callout_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v5.proto.common.extensions_pb2.CalloutFeedItem
        ]: ...
        def __init__(
            self,
            *,
            callout_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v5.proto.common.extensions_pb2.CalloutFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "callout_extensions", b"callout_extensions"
            ],
        ) -> None: ...
    class CallExtensionParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CALL_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def call_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v5.proto.common.extensions_pb2.CallFeedItem
        ]: ...
        def __init__(
            self,
            *,
            call_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v5.proto.common.extensions_pb2.CallFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "call_extensions", b"call_extensions"
            ],
        ) -> None: ...
    class SitelinkExtensionParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SITELINK_EXTENSIONS_FIELD_NUMBER: builtins.int
        @property
        def sitelink_extensions(
            self,
        ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
            google.ads.google_ads.v5.proto.common.extensions_pb2.SitelinkFeedItem
        ]: ...
        def __init__(
            self,
            *,
            sitelink_extensions: typing.Optional[
                typing.Iterable[
                    google.ads.google_ads.v5.proto.common.extensions_pb2.SitelinkFeedItem
                ]
            ] = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "sitelink_extensions", b"sitelink_extensions"
            ],
        ) -> None: ...
    class MoveUnusedBudgetParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BUDGET_MICROS_TO_MOVE_FIELD_NUMBER: builtins.int
        @property
        def budget_micros_to_move(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            budget_micros_to_move: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "budget_micros_to_move", b"budget_micros_to_move"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "budget_micros_to_move", b"budget_micros_to_move"
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
    TEXT_AD_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    TARGET_CPA_OPT_IN_FIELD_NUMBER: builtins.int
    TARGET_ROAS_OPT_IN_FIELD_NUMBER: builtins.int
    CALLOUT_EXTENSION_FIELD_NUMBER: builtins.int
    CALL_EXTENSION_FIELD_NUMBER: builtins.int
    SITELINK_EXTENSION_FIELD_NUMBER: builtins.int
    MOVE_UNUSED_BUDGET_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def campaign_budget(
        self,
    ) -> global___ApplyRecommendationOperation.CampaignBudgetParameters: ...
    @property
    def text_ad(self) -> global___ApplyRecommendationOperation.TextAdParameters: ...
    @property
    def keyword(self) -> global___ApplyRecommendationOperation.KeywordParameters: ...
    @property
    def target_cpa_opt_in(
        self,
    ) -> global___ApplyRecommendationOperation.TargetCpaOptInParameters: ...
    @property
    def target_roas_opt_in(
        self,
    ) -> global___ApplyRecommendationOperation.TargetRoasOptInParameters: ...
    @property
    def callout_extension(
        self,
    ) -> global___ApplyRecommendationOperation.CalloutExtensionParameters: ...
    @property
    def call_extension(
        self,
    ) -> global___ApplyRecommendationOperation.CallExtensionParameters: ...
    @property
    def sitelink_extension(
        self,
    ) -> global___ApplyRecommendationOperation.SitelinkExtensionParameters: ...
    @property
    def move_unused_budget(
        self,
    ) -> global___ApplyRecommendationOperation.MoveUnusedBudgetParameters: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign_budget: typing.Optional[
            global___ApplyRecommendationOperation.CampaignBudgetParameters
        ] = ...,
        text_ad: typing.Optional[
            global___ApplyRecommendationOperation.TextAdParameters
        ] = ...,
        keyword: typing.Optional[
            global___ApplyRecommendationOperation.KeywordParameters
        ] = ...,
        target_cpa_opt_in: typing.Optional[
            global___ApplyRecommendationOperation.TargetCpaOptInParameters
        ] = ...,
        target_roas_opt_in: typing.Optional[
            global___ApplyRecommendationOperation.TargetRoasOptInParameters
        ] = ...,
        callout_extension: typing.Optional[
            global___ApplyRecommendationOperation.CalloutExtensionParameters
        ] = ...,
        call_extension: typing.Optional[
            global___ApplyRecommendationOperation.CallExtensionParameters
        ] = ...,
        sitelink_extension: typing.Optional[
            global___ApplyRecommendationOperation.SitelinkExtensionParameters
        ] = ...,
        move_unused_budget: typing.Optional[
            global___ApplyRecommendationOperation.MoveUnusedBudgetParameters
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "apply_parameters",
            b"apply_parameters",
            "call_extension",
            b"call_extension",
            "callout_extension",
            b"callout_extension",
            "campaign_budget",
            b"campaign_budget",
            "keyword",
            b"keyword",
            "move_unused_budget",
            b"move_unused_budget",
            "sitelink_extension",
            b"sitelink_extension",
            "target_cpa_opt_in",
            b"target_cpa_opt_in",
            "target_roas_opt_in",
            b"target_roas_opt_in",
            "text_ad",
            b"text_ad",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "apply_parameters",
            b"apply_parameters",
            "call_extension",
            b"call_extension",
            "callout_extension",
            b"callout_extension",
            "campaign_budget",
            b"campaign_budget",
            "keyword",
            b"keyword",
            "move_unused_budget",
            b"move_unused_budget",
            "resource_name",
            b"resource_name",
            "sitelink_extension",
            b"sitelink_extension",
            "target_cpa_opt_in",
            b"target_cpa_opt_in",
            "target_roas_opt_in",
            b"target_roas_opt_in",
            "text_ad",
            b"text_ad",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["apply_parameters", b"apply_parameters"],
    ) -> typing_extensions.Literal[
        "campaign_budget",
        "text_ad",
        "keyword",
        "target_cpa_opt_in",
        "target_roas_opt_in",
        "callout_extension",
        "call_extension",
        "sitelink_extension",
        "move_unused_budget",
    ]: ...

global___ApplyRecommendationOperation = ApplyRecommendationOperation

class ApplyRecommendationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ApplyRecommendationResult
    ]: ...
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[global___ApplyRecommendationResult]
        ] = ...,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___ApplyRecommendationResponse = ApplyRecommendationResponse

class ApplyRecommendationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___ApplyRecommendationResult = ApplyRecommendationResult

class DismissRecommendationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class DismissRecommendationOperation(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RESOURCE_NAME_FIELD_NUMBER: builtins.int
        resource_name: typing.Text = ...
        def __init__(
            self,
            *,
            resource_name: typing.Text = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["resource_name", b"resource_name"],
        ) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    @property
    def operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___DismissRecommendationRequest.DismissRecommendationOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operations: typing.Optional[
            typing.Iterable[
                global___DismissRecommendationRequest.DismissRecommendationOperation
            ]
        ] = ...,
        partial_failure: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
        ],
    ) -> None: ...

global___DismissRecommendationRequest = DismissRecommendationRequest

class DismissRecommendationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class DismissRecommendationResult(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RESOURCE_NAME_FIELD_NUMBER: builtins.int
        resource_name: typing.Text = ...
        def __init__(
            self,
            *,
            resource_name: typing.Text = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal["resource_name", b"resource_name"],
        ) -> None: ...
    RESULTS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___DismissRecommendationResponse.DismissRecommendationResult
    ]: ...
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        results: typing.Optional[
            typing.Iterable[
                global___DismissRecommendationResponse.DismissRecommendationResult
            ]
        ] = ...,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

global___DismissRecommendationResponse = DismissRecommendationResponse
